==> kdegraphics-4.2.4-i486-1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libksane.so )
( cd usr/lib ; ln -sf libksane.so.0 libksane.so )
( cd usr/lib ; rm -rf libgwenviewlib.so )
( cd usr/lib ; ln -sf libgwenviewlib.so.4 libgwenviewlib.so )
( cd usr/lib ; rm -rf libkdcraw.so )
( cd usr/lib ; ln -sf libkdcraw.so.7 libkdcraw.so )
( cd usr/lib ; rm -rf libksane.so.0 )
( cd usr/lib ; ln -sf libksane.so.0.1.2 libksane.so.0 )
( cd usr/lib ; rm -rf libkexiv2.so )
( cd usr/lib ; ln -sf libkexiv2.so.7 libkexiv2.so )
( cd usr/lib ; rm -rf libkipi.so.6 )
( cd usr/lib ; ln -sf libkipi.so.6.0.0 libkipi.so.6 )
( cd usr/lib ; rm -rf libkolourpaint_lgpl.so )
( cd usr/lib ; ln -sf libkolourpaint_lgpl.so.4 libkolourpaint_lgpl.so )
( cd usr/lib ; rm -rf libokularcore.so.1 )
( cd usr/lib ; ln -sf libokularcore.so.1.2.0 libokularcore.so.1 )
( cd usr/lib ; rm -rf libokularcore.so )
( cd usr/lib ; ln -sf libokularcore.so.1 libokularcore.so )
( cd usr/lib ; rm -rf libkipi.so )
( cd usr/lib ; ln -sf libkipi.so.6 libkipi.so )
( cd usr/lib ; rm -rf libkolourpaint_lgpl.so.4 )
( cd usr/lib ; ln -sf libkolourpaint_lgpl.so.4.2.0 libkolourpaint_lgpl.so.4 )
( cd usr/lib ; rm -rf libkdcraw.so.7 )
( cd usr/lib ; ln -sf libkdcraw.so.7.0.0 libkdcraw.so.7 )
( cd usr/lib ; rm -rf libgwenviewlib.so.4 )
( cd usr/lib ; ln -sf libgwenviewlib.so.4.2.0 libgwenviewlib.so.4 )
( cd usr/lib ; rm -rf libkexiv2.so.7 )
( cd usr/lib ; ln -sf libkexiv2.so.7.2.0 libkexiv2.so.7 )
( cd usr/share/doc/HTML/en/kcontrol/kamera ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kamera ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/okular ; rm -rf common )
( cd usr/share/doc/HTML/en/okular ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/en/kolourpaint ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgamma ; rm -rf common )
( cd usr/share/doc/HTML/en/kgamma ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kruler ; rm -rf common )
( cd usr/share/doc/HTML/en/kruler ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/en/ksnapshot ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/en/gwenview ; ln -sf /usr/share/doc/HTML/en/common common )

==> kdegraphics-4.4.3-i486-2.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libgwenviewlib.so.4 )
( cd usr/lib ; ln -sf libgwenviewlib.so.4.4.0 libgwenviewlib.so.4 )
( cd usr/lib ; rm -rf libkipi.so.7 )
( cd usr/lib ; ln -sf libkipi.so.7.0.0 libkipi.so.7 )
( cd usr/lib ; rm -rf libkexiv2.so )
( cd usr/lib ; ln -sf libkexiv2.so.8 libkexiv2.so )
( cd usr/lib ; rm -rf libkolourpaint_lgpl.so.4 )
( cd usr/lib ; ln -sf libkolourpaint_lgpl.so.4.4.0 libkolourpaint_lgpl.so.4 )
( cd usr/lib ; rm -rf libkolourpaint_lgpl.so )
( cd usr/lib ; ln -sf libkolourpaint_lgpl.so.4 libkolourpaint_lgpl.so )
( cd usr/lib ; rm -rf libgwenviewlib.so )
( cd usr/lib ; ln -sf libgwenviewlib.so.4 libgwenviewlib.so )
( cd usr/lib ; rm -rf libkdcraw.so )
( cd usr/lib ; ln -sf libkdcraw.so.8 libkdcraw.so )
( cd usr/lib ; rm -rf libokularcore.so )
( cd usr/lib ; ln -sf libokularcore.so.1 libokularcore.so )
( cd usr/lib ; rm -rf libksane.so.0 )
( cd usr/lib ; ln -sf libksane.so.0.2.0 libksane.so.0 )
( cd usr/lib ; rm -rf libokularcore.so.1 )
( cd usr/lib ; ln -sf libokularcore.so.1.4.0 libokularcore.so.1 )
( cd usr/lib ; rm -rf libksane.so )
( cd usr/lib ; ln -sf libksane.so.0 libksane.so )
( cd usr/lib ; rm -rf libkipi.so )
( cd usr/lib ; ln -sf libkipi.so.7 libkipi.so )
( cd usr/lib ; rm -rf libkexiv2.so.8 )
( cd usr/lib ; ln -sf libkexiv2.so.8.0.0 libkexiv2.so.8 )
( cd usr/lib ; rm -rf libkdcraw.so.8 )
( cd usr/lib ; ln -sf libkdcraw.so.8.0.0 libkdcraw.so.8 )
( cd usr/share/doc/HTML/en/okular ; rm -rf common )
( cd usr/share/doc/HTML/en/okular ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kruler ; rm -rf common )
( cd usr/share/doc/HTML/en/kruler ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/en/kolourpaint ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/en/ksnapshot ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/en/gwenview ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kgamma ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kgamma ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kamera ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kamera ; ln -sf /usr/share/doc/HTML/en/common common )
